The hardware and bandwidth for this mirror is donated by METANET, the Webhosting and Full Service-Cloud Provider.
If you wish to report a bug, or if you are interested in having us mirror your free-software or open-source project, please feel free to contact us at mirror[@]metanet.ch.

Package {OlympicRshiny}


Title: 'Shiny' Application for Olympic Data
Version: 1.1.0
Description: Provides a 'Shiny' application for exploring and visualizing Olympic Games data from 1896 onwards, including both Summer and Winter Olympic Games. The application provides interactive visualizations of athletes, countries, sports, events, and medal results. Olympic data are obtained from the 'olympicAthletes' R package.
License: MIT + file LICENSE
URL: https://github.com/Amalan-ConStat/OlympicRshiny,https://amalan-con-stat.shinyapps.io/OlympicRshiny/
BugReports: https://github.com/Amalan-ConStat/OlympicRshiny/issues
Depends: R (≥ 4.1.0)
Imports: config, dplyr, forcats, ggplot2, golem, shiny, shinybusy, shinythemes
Suggests: olympicAthletes,
Encoding: UTF-8
LazyData: true
LazyDataCompression: xz
Config/roxygen2/version: 8.1.0
NeedsCompilation: no
Packaged: 2026-10-03 13:53:54 UTC; amala
Author: Amalan Mahendran [cre, aut]
Maintainer: Amalan Mahendran <amalan0595@gmail.com>
Repository: CRAN
Date/Publication: 2026-10-03 14:10:02 UTC

Olympic data

Description

Olympic athlete-event data from 1896 onwards, including both Summer and Winter Olympic Games. The data are obtained from the olympicAthletes R package and reformatted for use in OlympicRshiny.

Usage

Olympic

Format

A data frame with the following variables:

ID

Unique athlete identifier.

Name

Athlete's name.

Sex

Sex of the athlete: Male or Female.

Age

Age of the athlete in years.

Height

Height of the athlete in centimeters.

Weight

Weight of the athlete in kilograms.

Team

Team name.

Games

Olympic Games, identified by year and season.

Year

Year in which the Olympic Games were held.

Season

Olympic Games season: Summer or Winter.

City

Host city of the Olympic Games.

Sport

Sport in which the athlete participated.

Event

Event in which the athlete participated.

Medal

Medal won: Gold, Silver, Bronze, or NA if no medal was won.

NOC

Region corresponding to the athlete's National Olympic Committee code.

The Olympic athlete-event data are obtained from the olympicAthletes R package.

Examples

plot(Olympic$Height,Olympic$Weight)


Run the Shiny Application

Description

Run the Shiny Application

Usage

run_app(...)

Arguments

...

list of golem options.

Value

used for side effects

These binaries (installable software) and packages are in development.
They may not be fully stable and should be used with caution. We make no claims about them.